@@ -127,7 +127,9 @@ static int foc_handler_run(FAR struct foc_motor_f32_s *motor,
 
   /* Get FOC handler state */
 
-  foc_handler_state_f32(&motor->handler, &motor->foc_state);
+  foc_handler_state_f32(&motor->handler,
+                        &motor->foc_state,
+                        &motor->mod_state);
 
   return ret;
 }
@@ -192,7 +194,9 @@ static void foc_float_nxscope(FAR struct foc_nxscope_s *nxs,
   int        i = nxs->ch_per_inst * motor->envp->id;
 #endif
 
+#ifndef CONFIG_EXAMPLES_FOC_NXSCOPE_CONTROL
   nxscope_lock(&nxs->nxs);
+#endif
 
 #if (CONFIG_EXAMPLES_FOC_NXSCOPE_CFG & FOC_NXSCOPE_IABC)
   ptr = (FAR float *)&motor->foc_state.curr;
@@ -227,12 +231,12 @@ static void foc_float_nxscope(FAR struct foc_nxscope_s *nxs,
   nxscope_put_vfloat(&nxs->nxs, i++, ptr, 1);
 #endif
 #if (CONFIG_EXAMPLES_FOC_NXSCOPE_CFG & FOC_NXSCOPE_VEL)
-#  warning not supported yet
-  i++;
+  ptr = (FAR float *)&motor->vel_el;
+  nxscope_put_vfloat(&nxs->nxs, i++, ptr, 1);
 #endif
 #if (CONFIG_EXAMPLES_FOC_NXSCOPE_CFG & FOC_NXSCOPE_VM)
-#  warning not supported yet
-  i++;
+  ptr = (FAR float *)&motor->vel_mech;
+  nxscope_put_vfloat(&nxs->nxs, i++, ptr, 1);
 #endif
 #if (CONFIG_EXAMPLES_FOC_NXSCOPE_CFG & FOC_NXSCOPE_VBUS)
   ptr = (FAR float *)&motor->vbus;
@@ -258,8 +262,36 @@ static void foc_float_nxscope(FAR struct foc_nxscope_s *nxs,
   ptr = (FAR float *)&motor->vdq_comp;
   nxscope_put_vfloat(&nxs->nxs, i++, ptr, 2);
 #endif
+#if (CONFIG_EXAMPLES_FOC_NXSCOPE_CFG & FOC_NXSCOPE_SVM3)
+  float svm3_tmp[4];
 
+  /* Convert sector to float.
+   * Normally, a sector value is an integer in the range 1-6 but we convert
+   * it to float and range to 0.1-0.6. This is to send the entire SVM3 state
+   * as float array and scale the sector value closer to PWM duty values
+   * (range 0.0 to 0.5) which makes it easier to visualize the data later.
+   */
+
+  svm3_tmp[0] = (float)motor->mod_state.sector * 0.1f;
+  svm3_tmp[1] = motor->mod_state.d_u;
+  svm3_tmp[2] = motor->mod_state.d_v;
+  svm3_tmp[3] = motor->mod_state.d_w;
+
+  ptr = svm3_tmp;
+  nxscope_put_vfloat(&nxs->nxs, i++, ptr, 4);
+#endif
+#if (CONFIG_EXAMPLES_FOC_NXSCOPE_CFG & FOC_NXSCOPE_VOBS)
+  ptr = (FAR float *)&motor->vel_obs;
+  nxscope_put_vfloat(&nxs->nxs, i++, ptr, 1);
+#endif
+#if (CONFIG_EXAMPLES_FOC_NXSCOPE_CFG & FOC_NXSCOPE_AOBS)
+  ptr = (FAR float *)&motor->angle_obs;
+  nxscope_put_vfloat(&nxs->nxs, i++, ptr, 1);
+#endif
+
+#ifndef CONFIG_EXAMPLES_FOC_NXSCOPE_CONTROL
   nxscope_unlock(&nxs->nxs);
+#endif
 }
 #endif
 
@@ -276,10 +308,8 @@ int foc_float_thr(FAR struct foc_ctrl_env_s *envp)
   struct foc_mq_s         handle;
   struct foc_motor_f32_s  motor;
   struct foc_device_s     dev;
-  int                     time = 0;
   int                     ret  = OK;
 
-  UNUSED(time);
   DEBUGASSERT(envp);
 
   PRINTFV("foc_float_thr, id=%d\n", envp->id);
@@ -306,9 +336,10 @@ int foc_float_thr(FAR struct foc_ctrl_env_s *envp)
       goto errout;
     }
 
-  /* Get PWM max duty */
+  /* Store data from device */
 
   motor.pwm_duty_max = FOCDUTY_TO_FLOAT(dev.info.hw_cfg.pwm_max);
+  motor.iphase_adc = dev.info.hw_cfg.iphase_scale / 100000.0f;
 
   /* Start with motor free */
 
@@ -322,7 +353,19 @@ int foc_float_thr(FAR struct foc_ctrl_env_s *envp)
 
   while (motor.mq.quit == false)
     {
-      PRINTFV("foc_float_thr %d %d\n", envp->id, time);
+      if (motor.mq.start == true)
+        {
+          /* Get FOC device state */
+
+          ret = foc_dev_state_get(&dev);
+          if (ret < 0)
+            {
+              PRINTF("ERROR: foc_dev_state_get failed %d!\n", ret);
+              goto errout;
+            }
+        }
+
+      PRINTFV("foc_float_thr %d %d\n", envp->id, motor.time);
 
       /* Handle mqueue */
 
@@ -357,119 +400,129 @@ int foc_float_thr(FAR struct foc_ctrl_env_s *envp)
             }
 
           motor.startstop = false;
+
+          /* Start from the beginning of the control loop */
+
+          continue;
         }
 
-      /* Run control logic if controller started */
+      /* Ignore control logic if controller not started yet */
 
-      if (motor.mq.start == true)
-        {
-          /* Get FOC device state */
-
-          ret = foc_dev_state_get(&dev);
-          if (ret < 0)
-            {
-              PRINTF("ERROR: foc_dev_state_get failed %d!\n", ret);
-              goto errout;
-            }
-
-#ifdef CONFIG_EXAMPLES_FOC_STATE_USE_MODEL_PMSM
-          /* Get model state */
-
-          ret = foc_model_state_get(&motor, &dev);
-          if (ret < 0)
-            {
-              PRINTF("ERROR: foc_model_state_get failed %d!\n", ret);
-              goto errout;
-            }
-#endif
-
-          /* Handle controller state */
-
-          ret = foc_dev_state_handle(&dev, &motor.fault);
-          if (ret < 0)
-            {
-              PRINTF("ERROR: foc_dev_state_handle failed %d!\n", ret);
-              goto errout;
-            }
-
-          /* Get motor state */
-
-          ret = foc_motor_get(&motor);
-          if (ret < 0)
-            {
-              PRINTF("ERROR: foc_motor_get failed %d!\n", ret);
-              goto errout;
-            }
-
-          /* Motor control */
-
-          ret = foc_motor_control(&motor);
-          if (ret < 0)
-            {
-              PRINTF("ERROR: foc_motor_control failed %d!\n", ret);
-              goto errout;
-            }
-
-          /* Run FOC */
-
-          ret = foc_handler_run(&motor, &dev);
-          if (ret < 0)
-            {
-              PRINTF("ERROR: foc_handler_run failed %d!\n", ret);
-              goto errout;
-            }
-
-#ifdef FOC_STATE_PRINT_PRE
-          /* Print state if configured */
-
-          if (time % FOC_STATE_PRINT_PRE == 0)
-            {
-              foc_state_print(&motor);
-            }
-#endif
-
-#ifdef CONFIG_EXAMPLES_FOC_NXSCOPE
-          /* Capture nxscope samples */
-
-          if (time % CONFIG_EXAMPLES_FOC_NXSCOPE_PRESCALER == 0)
-            {
-              foc_float_nxscope(envp->nxs, &motor, &dev);
-            }
-#endif
-
-#ifdef CONFIG_EXAMPLES_FOC_STATE_USE_MODEL_PMSM
-          /* Feed FOC model with data */
-
-          foc_model_run_f32(&motor.model,
-                            FOC_MODEL_LOAD,
-                            &motor.foc_state.vab);
-#endif
-
-          /* Set FOC device parameters */
-
-          ret = foc_dev_params_set(&dev);
-          if (ret < 0)
-            {
-              PRINTF("ERROR: foc_dev_prams_set failed %d!\n", ret);
-              goto errout;
-            }
-
-          /* Terminate control thread */
-
-          if (motor.ctrl_state == FOC_CTRL_STATE_TERMINATE)
-            {
-              PRINTF("TERMINATE CTRL THREAD\n");
-              goto errout;
-            }
-        }
-      else
+      if (motor.mq.start == false)
         {
           usleep(1000);
+          continue;
+        }
+
+#ifdef CONFIG_EXAMPLES_FOC_STATE_USE_MODEL_PMSM
+      /* Get model state */
+
+      ret = foc_model_state_get(&motor, &dev);
+      if (ret < 0)
+        {
+          PRINTF("ERROR: foc_model_state_get failed %d!\n", ret);
+          goto errout;
+        }
+#endif
+
+      /* Handle controller state */
+
+      ret = foc_dev_state_handle(&dev, &motor.fault);
+      if (ret < 0)
+        {
+          PRINTF("ERROR: foc_dev_state_handle failed %d!\n", ret);
+          goto errout;
+        }
+
+      /* Get motor state */
+
+      ret = foc_motor_get(&motor);
+      if (ret < 0)
+        {
+          PRINTF("ERROR: foc_motor_get failed %d!\n", ret);
+          goto errout;
+        }
+
+      /* Motor control */
+
+      ret = foc_motor_control(&motor);
+      if (ret < 0)
+        {
+          PRINTF("ERROR: foc_motor_control failed %d!\n", ret);
+          goto errout;
+        }
+
+      /* Run FOC */
+
+      ret = foc_handler_run(&motor, &dev);
+      if (ret < 0)
+        {
+          PRINTF("ERROR: foc_handler_run failed %d!\n", ret);
+          goto errout;
+        }
+
+#ifdef FOC_STATE_PRINT_PRE
+      /* Print state if configured */
+
+      if (motor.time % FOC_STATE_PRINT_PRE == 0)
+        {
+          foc_state_print(&motor);
+        }
+#endif
+
+#ifdef CONFIG_EXAMPLES_FOC_STATE_USE_MODEL_PMSM
+      /* Feed FOC model with data */
+
+      foc_model_run_f32(&motor.model,
+                        FOC_MODEL_LOAD,
+                        &motor.foc_state.vab);
+#endif
+
+      /* Set FOC device parameters */
+
+      ret = foc_dev_params_set(&dev);
+      if (ret < 0)
+        {
+          PRINTF("ERROR: foc_dev_prams_set failed %d!\n", ret);
+          goto errout;
+        }
+
+#ifdef CONFIG_EXAMPLES_FOC_NXSCOPE
+      /* Capture nxscope samples */
+
+      if (motor.time % CONFIG_EXAMPLES_FOC_NXSCOPE_PRESCALER == 0)
+        {
+          foc_float_nxscope(envp->nxs, &motor, &dev);
+        }
+#endif
+
+#ifdef CONFIG_EXAMPLES_FOC_NXSCOPE_CONTROL
+      /* Handle nxscope work */
+
+      if (motor.time % CONFIG_EXAMPLES_FOC_NXSCOPE_WORK_PRESCALER == 0)
+        {
+          foc_nxscope_work(envp->nxs);
+        }
+#endif
+
+      /* Terminate control thread */
+
+      if (motor.ctrl_state == FOC_CTRL_STATE_TERMINATE)
+        {
+          PRINTF("TERMINATE CTRL THREAD\n");
+          goto errout;
         }
 
       /* Increase counter */
 
-      time += 1;
+      motor.time += 1;
+
+#ifdef CONFIG_EXAMPLES_FOC_PERF
+      if (dev.perf.max_changed)
+        {
+          PRINTF_PERF("max=%" PRId32 "\n", dev.perf.max);
+        }
+#endif
     }
 
 errout:
