@@ -75,7 +75,12 @@ struct args_s g_args =
     .fmode = CONFIG_EXAMPLES_FOC_FMODE,
     .mmode = CONFIG_EXAMPLES_FOC_MMODE,
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_OPENLOOP
-    .qparam = CONFIG_EXAMPLES_FOC_OPENLOOP_Q,
+    .qparam   = CONFIG_EXAMPLES_FOC_OPENLOOP_Q,
+    .ol_force = false,
+#  ifdef CONFIG_EXAMPLES_FOC_ANGOBS
+    .ol_hys = CONFIG_EXAMPLES_FOC_ANGOBS_HYS,
+    .ol_thr = CONFIG_EXAMPLES_FOC_ANGOBS_THR,
+#  endif
 #endif
 #ifdef CONFIG_EXAMPLES_FOC_CONTROL_PI
     .foc_pi_kp = CONFIG_EXAMPLES_FOC_IDQ_KP,
@@ -102,12 +107,35 @@ struct args_s g_args =
     .posmax = CONFIG_EXAMPLES_FOC_SETPOINT_MAX,
 #  endif
 #endif
+#ifdef CONFIG_EXAMPLES_FOC_HAVE_VEL
+    .acc = CONFIG_EXAMPLES_FOC_RAMP_ACC,
+    .dec = CONFIG_EXAMPLES_FOC_RAMP_DEC,
+#endif
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_IDENT
     .ident_res_ki = CONFIG_EXAMPLES_FOC_IDENT_RES_KI,
     .ident_res_curr = CONFIG_EXAMPLES_FOC_IDENT_RES_CURRENT,
     .ident_res_sec = CONFIG_EXAMPLES_FOC_IDENT_RES_SEC,
     .ident_ind_volt = CONFIG_EXAMPLES_FOC_IDENT_IND_VOLTAGE,
     .ident_ind_sec = CONFIG_EXAMPLES_FOC_IDENT_IND_SEC,
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_HAVE_VEL
+    .vel_filter = CONFIG_EXAMPLES_FOC_VELNOW_FILTER,
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_VELOBS_PLL
+    .vel_pll_kp = CONFIG_EXAMPLES_FOC_VELOBS_PLL_KP,
+    .vel_pll_ki = CONFIG_EXAMPLES_FOC_VELOBS_PLL_KI,
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_VELOBS_DIV
+    .vel_div_samples = CONFIG_EXAMPLES_FOC_VELOBS_DIV_SAMPLES,
+    .vel_div_filter = CONFIG_EXAMPLES_FOC_VELOBS_DIV_FILTER,
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_VELCTRL_PI
+    .vel_pi_kp = CONFIG_EXAMPLES_FOC_VELCTRL_PI_KP,
+    .vel_pi_ki = CONFIG_EXAMPLES_FOC_VELCTRL_PI_KI,
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_ANGOBS_NFO
+    .ang_nfo_slow = CONFIG_EXAMPLES_FOC_ANGOBS_NFO_GAINSLOW,
+    .ang_nfo_gain = CONFIG_EXAMPLES_FOC_ANGOBS_NFO_GAIN,
 #endif
   }
 };
@@ -368,8 +396,7 @@ int main(int argc, char *argv[])
     {
       PRINTFV("foc_main loop %d\n", time);
 
-#if defined(CONFIG_EXAMPLES_FOC_NXSCOPE) &&       \
-    !defined(CONFIG_EXAMPLES_FOC_NXSCOPE_THREAD)
+#ifdef CONFIG_EXAMPLES_FOC_NXSCOPE_MAIN
       foc_nxscope_work(&nxs);
 #endif
 
