@@ -80,32 +80,67 @@ struct foc_motor_b16_s
   /* FOC data ***************************************************************/
 
   struct foc_state_b16_s        foc_state;    /* FOC controller sate */
+#ifdef CONFIG_EXAMPLES_FOC_MODULATION_SVM3
+  struct svm3_state_b16_s       mod_state;    /* Modulation state */
+#endif
   foc_handler_b16_t             handler;      /* FOC controller */
   dq_frame_b16_t                dq_ref;       /* DQ reference */
   dq_frame_b16_t                vdq_comp;     /* DQ voltage compensation */
   int                           foc_mode;     /* FOC mode */
+  int                           time;         /* Helper counter */
   b16_t                         vbus;         /* Power bus voltage */
   b16_t                         per;          /* Controller period in seconds */
+#ifdef CONFIG_EXAMPLES_FOC_ANGOBS
+  b16_t                         ol_thr;       /* Angle observer threshold velocity */
+  b16_t                         ol_hys;       /* Angle observer hysteresis */
+  b16_t                         angle_step;   /* Open-loop transition step */
+#endif
+
+  /* Data from FOC device ***************************************************/
+
   b16_t                         iphase_adc;   /* Iphase ADC scaling factor */
   b16_t                         pwm_duty_max; /* PWM duty max */
 
   /* Velocity controller data ***********************************************/
 
   struct foc_ramp_b16_s         ramp;         /* Velocity ramp data */
+#ifdef CONFIG_EXAMPLES_FOC_VELCTRL_PI
+  pid_controller_b16_t          vel_pi;       /* Velocity controller */
+#endif
 
-  /* Motor state ************************************************************/
+  /* Angle state ************************************************************/
 
   b16_t                         angle_now;    /* Phase angle now */
   b16_t                         angle_m;      /* Motor mechanical angle */
   b16_t                         angle_el;     /* Motor electrical angle */
+#ifdef CONFIG_EXAMPLES_FOC_HAVE_OPENLOOP
+  b16_t                         angle_ol;     /* Phase angle open-loop */
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_ANGOBS
+  b16_t                         angle_obs;    /* Angle observer output */
+  b16_t                         angle_err;    /* Open-loop to observer error */
+#endif
+
+  /* Velocity state *********************************************************/
+
+#ifdef CONFIG_EXAMPLES_FOC_HAVE_VEL
+  b16_t                         vel_el;       /* Velocity - electrical */
+  b16_t                         vel_mech;     /* Velocity - mechanical */
+  b16_t                         vel_filter;   /* Velocity low-pass filter */
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_VELOBS
+  b16_t                         vel_obs;      /* Velocity observer output */
+#endif
 
   /* Motor setpoints ********************************************************/
 
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_TORQ
   struct foc_setpoint_b16_s     torq;         /* Torque setpoint */
+  b16_t                         torq_sat;     /* Torque saturation */
 #endif
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_VEL
   struct foc_setpoint_b16_s     vel;          /* Velocity setpoint */
+  b16_t                         vel_sat;      /* Velocity saturation */
 #endif
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_POS
   struct foc_setpoint_b16_s     pos;          /* Position setpoint */
@@ -130,14 +165,14 @@ struct foc_motor_b16_s
   struct foc_model_b16_s        model;        /* Model handler */
   struct foc_model_state_b16_s  model_state;  /* PMSM model state */
 #endif
-  uint8_t                       poles;        /* Motor poles */
+  struct motor_phy_params_b16_s phy;          /* Motor phy */
 
   /* Motor velocity and angle handlers **************************************/
 
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_OPENLOOP
   foc_angle_b16_t               openloop;     /* Open-loop angle handler */
-  bool                          openloop_now; /* Open-loop now */
-  b16_t                         angle_ol;     /* Phase angle open-loop */
+  uint8_t                       openloop_now; /* Open-loop now */
+  b16_t                         openloop_q;   /* Open-loop Q parameter */
 #endif
 #ifdef CONFIG_EXAMPLES_FOC_HAVE_HALL
   foc_angle_b16_t               hall;         /* Hall angle handler */
@@ -147,6 +182,18 @@ struct foc_motor_b16_s
   foc_angle_b16_t               qenco;        /* Qenco angle handler */
   char                          qedpath[32];  /* Qenco devpath */
 #endif
+#ifdef CONFIG_EXAMPLES_FOC_VELOBS_DIV
+  foc_velocity_b16_t            vel_div;       /* DIV velocity observer */
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_VELOBS_PLL
+  foc_velocity_b16_t            vel_pll;       /* PLL velocity observer */
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_ANGOBS_SMO
+  foc_angle_b16_t               ang_smo;      /* SMO angle observer */
+#endif
+#ifdef CONFIG_EXAMPLES_FOC_ANGOBS_NFO
+  foc_angle_b16_t               ang_nfo;      /* NFO angle observer */
+#endif
 };
 
 /****************************************************************************
