@@ -647,7 +647,8 @@ int main(int argc, FAR char *argv[])
 
       /* read a line from the terminal */
 
-      len = readline(buffer, sizeof(buffer), stdin, stdout);
+      len = readline_stream(buffer, sizeof(buffer),
+                            stdin, stdout);
       buffer[len] = '\0';
       if (len > 0)
         {
