@@ -214,153 +214,153 @@ static void printName(const void *k, struct Program *p, int chn)
  * Public Functions
  ****************************************************************************/
 
-struct Program *Program_new(struct Program *this)
+struct Program *Program_new(struct Program *self)
 {
-  this->trace = 0;
-  this->size = 0;
-  this->numbered = 1;
-  this->capacity = 0;
-  this->runnable = 0;
-  this->unsaved = 0;
-  this->code = (struct Token **)0;
-  this->scope = (struct Scope *)0;
-  String_new(&this->name);
-  return this;
+  self->trace = 0;
+  self->size = 0;
+  self->numbered = 1;
+  self->capacity = 0;
+  self->runnable = 0;
+  self->unsaved = 0;
+  self->code = (struct Token **)0;
+  self->scope = (struct Scope *)0;
+  String_new(&self->name);
+  return self;
 }
 
-void Program_destroy(struct Program *this)
+void Program_destroy(struct Program *self)
 {
-  while (this->size)
+  while (self->size)
     {
-      Token_destroy(this->code[--this->size]);
+      Token_destroy(self->code[--self->size]);
     }
 
-  if (this->capacity)
+  if (self->capacity)
     {
-      free(this->code);
+      free(self->code);
     }
 
-  this->code = (struct Token **)0;
-  this->scope = (struct Scope *)0;
-  String_destroy(&this->name);
+  self->code = (struct Token **)0;
+  self->scope = (struct Scope *)0;
+  String_destroy(&self->name);
 }
 
-void Program_norun(struct Program *this)
+void Program_norun(struct Program *self)
 {
-  this->runnable = 0;
-  this->scope = (struct Scope *)0;
+  self->runnable = 0;
+  self->scope = (struct Scope *)0;
 }
 
-void Program_store(struct Program *this, struct Token *line, long int where)
+void Program_store(struct Program *self, struct Token *line, long int where)
 {
   int i;
 
   assert(line->type == T_INTEGER || line->type == T_UNNUMBERED);
-  this->runnable = 0;
-  this->unsaved = 1;
+  self->runnable = 0;
+  self->unsaved = 1;
   if (line->type == T_UNNUMBERED)
     {
-      this->numbered = 0;
+      self->numbered = 0;
     }
 
   if (where)
     {
       int last = -1;
 
-      for (i = 0; i < this->size; ++i)
+      for (i = 0; i < self->size; ++i)
         {
-          assert(this->code[i]->type == T_INTEGER ||
-                 this->code[i]->type == T_UNNUMBERED);
-          if (where > last && where < this->code[i]->u.integer)
+          assert(self->code[i]->type == T_INTEGER ||
+                 self->code[i]->type == T_UNNUMBERED);
+          if (where > last && where < self->code[i]->u.integer)
             {
-              if ((this->size + 1) >= this->capacity)
+              if ((self->size + 1) >= self->capacity)
                 {
-                  this->code =
-                    realloc(this->code,
+                  self->code =
+                    realloc(self->code,
                             sizeof(struct Token *) *
-                            (this->capacity ? (this->capacity *=
-                                               2) : (this->capacity = 256)));
+                            (self->capacity ? (self->capacity *=
+                                               2) : (self->capacity = 256)));
                 }
 
-              memmove(&this->code[i + 1], &this->code[i],
-                      (this->size - i) * sizeof(struct Token *));
-              this->code[i] = line;
-              ++this->size;
+              memmove(&self->code[i + 1], &self->code[i],
+                      (self->size - i) * sizeof(struct Token *));
+              self->code[i] = line;
+              ++self->size;
               return;
             }
-          else if (where == this->code[i]->u.integer)
+          else if (where == self->code[i]->u.integer)
             {
-              Token_destroy(this->code[i]);
-              this->code[i] = line;
+              Token_destroy(self->code[i]);
+              self->code[i] = line;
               return;
             }
 
-          last = this->code[i]->u.integer;
+          last = self->code[i]->u.integer;
         }
     }
   else
     {
-      i = this->size;
+      i = self->size;
     }
 
-  if ((this->size + 1) >= this->capacity)
+  if ((self->size + 1) >= self->capacity)
     {
-      this->code =
-        realloc(this->code,
+      self->code =
+        realloc(self->code,
                 sizeof(struct Token *) *
-                (this->capacity ? (this->capacity *= 2)
-                 : (this->capacity = 256)));
+                (self->capacity ? (self->capacity *= 2)
+                 : (self->capacity = 256)));
     }
 
-  this->code[i] = line;
-  ++this->size;
+  self->code[i] = line;
+  ++self->size;
 }
 
-void Program_delete(struct Program *this, const struct Pc *from,
+void Program_delete(struct Program *self, const struct Pc *from,
                     const struct Pc *to)
 {
   int i;
   int first;
   int last;
 
-  this->runnable = 0;
-  this->unsaved = 1;
+  self->runnable = 0;
+  self->unsaved = 1;
   first = from ? from->line : 0;
-  last = to ? to->line : this->size - 1;
+  last = to ? to->line : self->size - 1;
   for (i = first; i <= last; ++i)
     {
-      Token_destroy(this->code[i]);
+      Token_destroy(self->code[i]);
     }
 
-  if ((last + 1) != this->size)
+  if ((last + 1) != self->size)
     {
-      memmove(&this->code[first], &this->code[last + 1],
-              (this->size - last + 1) * sizeof(struct Token *));
+      memmove(&self->code[first], &self->code[last + 1],
+              (self->size - last + 1) * sizeof(struct Token *));
     }
 
-  this->size -= (last - first + 1);
+  self->size -= (last - first + 1);
 }
 
-void Program_addScope(struct Program *this, struct Scope *scope)
+void Program_addScope(struct Program *self, struct Scope *scope)
 {
   struct Scope *s;
 
-  s = this->scope;
-  this->scope = scope;
+  s = self->scope;
+  self->scope = scope;
   scope->next = s;
 }
 
-struct Pc *Program_goLine(struct Program *this, long int line, struct Pc *pc)
+struct Pc *Program_goLine(struct Program *self, long int line, struct Pc *pc)
 {
   int i;
 
-  for (i = 0; i < this->size; ++i)
+  for (i = 0; i < self->size; ++i)
     {
-      if (this->code[i]->type == T_INTEGER &&
-          line == this->code[i]->u.integer)
+      if (self->code[i]->type == T_INTEGER &&
+          line == self->code[i]->u.integer)
         {
           pc->line = i;
-          pc->token = this->code[i] + 1;
+          pc->token = self->code[i] + 1;
           return pc;
         }
     }
@@ -368,18 +368,18 @@ struct Pc *Program_goLine(struct Program *this, long int line, struct Pc *pc)
   return (struct Pc *)0;
 }
 
-struct Pc *Program_fromLine(struct Program *this, long int line,
+struct Pc *Program_fromLine(struct Program *self, long int line,
                             struct Pc *pc)
 {
   int i;
 
-  for (i = 0; i < this->size; ++i)
+  for (i = 0; i < self->size; ++i)
     {
-      if (this->code[i]->type == T_INTEGER &&
-          this->code[i]->u.integer >= line)
+      if (self->code[i]->type == T_INTEGER &&
+          self->code[i]->u.integer >= line)
         {
           pc->line = i;
-          pc->token = this->code[i] + 1;
+          pc->token = self->code[i] + 1;
           return pc;
         }
     }
@@ -387,17 +387,17 @@ struct Pc *Program_fromLine(struct Program *this, long int line,
   return (struct Pc *)0;
 }
 
-struct Pc *Program_toLine(struct Program *this, long int line, struct Pc *pc)
+struct Pc *Program_toLine(struct Program *self, long int line, struct Pc *pc)
 {
   int i;
 
-  for (i = this->size - 1; i >= 0; --i)
+  for (i = self->size - 1; i >= 0; --i)
     {
-      if (this->code[i]->type == T_INTEGER &&
-          this->code[i]->u.integer <= line)
+      if (self->code[i]->type == T_INTEGER &&
+          self->code[i]->u.integer <= line)
         {
           pc->line = i;
-          pc->token = this->code[i] + 1;
+          pc->token = self->code[i] + 1;
           return pc;
         }
     }
@@ -405,13 +405,13 @@ struct Pc *Program_toLine(struct Program *this, long int line, struct Pc *pc)
   return (struct Pc *)0;
 }
 
-int Program_scopeCheck(struct Program *this, struct Pc *pc, struct Pc *fn)
+int Program_scopeCheck(struct Program *self, struct Pc *pc, struct Pc *fn)
 {
   struct Scope *scope;
 
   if (fn == (struct Pc *)0)     /* jump from global block must go to global pc */
     {
-      for (scope = this->scope; scope; scope = scope->next)
+      for (scope = self->scope; scope; scope = scope->next)
         {
           if (pc->line < scope->begin.line)
             {
@@ -467,10 +467,10 @@ int Program_scopeCheck(struct Program *this, struct Pc *pc, struct Pc *fn)
   return 0;
 }
 
-struct Pc *Program_dataLine(struct Program *this, long int line,
+struct Pc *Program_dataLine(struct Program *self, long int line,
                             struct Pc *pc)
 {
-  if ((pc = Program_goLine(this, line, pc)) == (struct Pc *)0)
+  if ((pc = Program_goLine(self, line, pc)) == (struct Pc *)0)
     {
       return (struct Pc *)0;
     }
@@ -490,10 +490,10 @@ struct Pc *Program_dataLine(struct Program *this, long int line,
   return pc;
 }
 
-struct Pc *Program_imageLine(struct Program *this, long int line,
+struct Pc *Program_imageLine(struct Program *self, long int line,
                              struct Pc *pc)
 {
-  if ((pc = Program_goLine(this, line, pc)) == (struct Pc *)0)
+  if ((pc = Program_goLine(self, line, pc)) == (struct Pc *)0)
     {
       return (struct Pc *)0;
     }
@@ -519,16 +519,16 @@ struct Pc *Program_imageLine(struct Program *this, long int line,
   return pc;
 }
 
-long int Program_lineNumber(const struct Program *this, const struct Pc *pc)
+long int Program_lineNumber(const struct Program *self, const struct Pc *pc)
 {
   if (pc->line == -1)
     {
       return 0;
     }
 
-  if (this->numbered)
+  if (self->numbered)
     {
-      return (this->code[pc->line]->u.integer);
+      return (self->code[pc->line]->u.integer);
     }
   else
     {
@@ -536,30 +536,30 @@ long int Program_lineNumber(const struct Program *this, const struct Pc *pc)
     }
 }
 
-struct Pc *Program_beginning(struct Program *this, struct Pc *pc)
+struct Pc *Program_beginning(struct Program *self, struct Pc *pc)
 {
-  if (this->size == 0)
+  if (self->size == 0)
     {
       return (struct Pc *)0;
     }
   else
     {
       pc->line = 0;
-      pc->token = this->code[0] + 1;
+      pc->token = self->code[0] + 1;
       return pc;
     }
 }
 
-struct Pc *Program_end(struct Program *this, struct Pc *pc)
+struct Pc *Program_end(struct Program *self, struct Pc *pc)
 {
-  if (this->size == 0)
+  if (self->size == 0)
     {
       return (struct Pc *)0;
     }
   else
     {
-      pc->line = this->size - 1;
-      pc->token = this->code[this->size - 1];
+      pc->line = self->size - 1;
+      pc->token = self->code[self->size - 1];
       while (pc->token->type != T_EOL)
         {
           ++pc->token;
@@ -569,31 +569,31 @@ struct Pc *Program_end(struct Program *this, struct Pc *pc)
     }
 }
 
-struct Pc *Program_nextLine(struct Program *this, struct Pc *pc)
+struct Pc *Program_nextLine(struct Program *self, struct Pc *pc)
 {
-  if (pc->line + 1 == this->size)
+  if (pc->line + 1 == self->size)
     {
       return (struct Pc *)0;
     }
   else
     {
-      pc->token = this->code[++pc->line] + 1;
+      pc->token = self->code[++pc->line] + 1;
       return pc;
     }
 }
 
-int Program_skipEOL(struct Program *this, struct Pc *pc, int dev, int tr)
+int Program_skipEOL(struct Program *self, struct Pc *pc, int dev, int tr)
 {
   if (pc->token->type == T_EOL)
     {
-      if (pc->line == -1 || pc->line + 1 == this->size)
+      if (pc->line == -1 || pc->line + 1 == self->size)
         {
           return 0;
         }
       else
         {
-          pc->token = this->code[++pc->line] + 1;
-          Program_trace(this, pc, dev, tr);
+          pc->token = self->code[++pc->line] + 1;
+          Program_trace(self, pc, dev, tr);
           return 1;
         }
     }
@@ -603,32 +603,32 @@ int Program_skipEOL(struct Program *this, struct Pc *pc, int dev, int tr)
     }
 }
 
-void Program_trace(struct Program *this, struct Pc *pc, int dev, int tr)
+void Program_trace(struct Program *self, struct Pc *pc, int dev, int tr)
 {
-  if (tr && this->trace && pc->line != -1)
+  if (tr && self->trace && pc->line != -1)
     {
       char buf[40];
 
       snprintf(buf, sizeof(buf), "<%ld>\n",
-               this->code[pc->line]->u.integer);
+               self->code[pc->line]->u.integer);
       FS_putChars(dev, buf);
     }
 }
 
-void Program_PCtoError(struct Program *this, struct Pc *pc, struct Value *v)
+void Program_PCtoError(struct Program *self, struct Pc *pc, struct Value *v)
 {
   struct String s;
 
   String_new(&s);
   if (pc->line >= 0)
     {
-      if (pc->line < (this->size - 1) || pc->token->type != T_EOL)
+      if (pc->line < (self->size - 1) || pc->token->type != T_EOL)
         {
           String_appendPrintf(&s, _(" in line %ld at:\n"),
-                              Program_lineNumber(this, pc));
-          Token_toString(this->code[pc->line], (struct Token *)0, &s,
+                              Program_lineNumber(self, pc));
+          Token_toString(self->code[pc->line], (struct Token *)0, &s,
                          (int *)0, -1);
-          Token_toString(this->code[pc->line], pc->token, &s, (int *)0, -1);
+          Token_toString(self->code[pc->line], pc->token, &s, (int *)0, -1);
           String_appendPrintf(&s, "^\n");
         }
       else
@@ -653,7 +653,7 @@ void Program_PCtoError(struct Program *this, struct Pc *pc, struct Value *v)
   String_destroy(&s);
 }
 
-struct Value *Program_merge(struct Program *this, int dev,
+struct Value *Program_merge(struct Program *self, int dev,
                             struct Value *value)
 {
   struct String s;
@@ -672,12 +672,12 @@ struct Value *Program_merge(struct Program *this, int dev,
           line = Token_newCode(s.character);
           if (line->type == T_INTEGER && line->u.integer > 0)
             {
-              Program_store(this, line,
-                            this->numbered ? line->u.integer : 0);
+              Program_store(self, line,
+                            self->numbered ? line->u.integer : 0);
             }
           else if (line->type == T_UNNUMBERED)
             {
-              Program_store(this, line, 0);
+              Program_store(self, line, 0);
             }
           else
             {
@@ -698,19 +698,19 @@ struct Value *Program_merge(struct Program *this, int dev,
   return (struct Value *)0;
 }
 
-int Program_lineNumberWidth(struct Program *this)
+int Program_lineNumberWidth(struct Program *self)
 {
   int i;
   int w = 0;
 
-  for (i = 0; i < this->size; ++i)
+  for (i = 0; i < self->size; ++i)
     {
-      if (this->code[i]->type == T_INTEGER)
+      if (self->code[i]->type == T_INTEGER)
         {
           int nw;
           int ln;
 
-          for (ln = this->code[i]->u.integer, nw = 1; ln /= 10; ++nw);
+          for (ln = self->code[i]->u.integer, nw = 1; ln /= 10; ++nw);
           if (nw > w)
             {
               w = nw;
@@ -721,7 +721,7 @@ int Program_lineNumberWidth(struct Program *this)
   return w;
 }
 
-struct Value *Program_list(struct Program *this, int dev, int watchIntr,
+struct Value *Program_list(struct Program *self, int dev, int watchIntr,
                            struct Pc *from, struct Pc *to,
                            struct Value *value)
 {
@@ -730,11 +730,11 @@ struct Value *Program_list(struct Program *this, int dev, int watchIntr,
   int indent = 0;
   struct String s;
 
-  w = Program_lineNumberWidth(this);
-  for (i = 0; i < this->size; ++i)
+  w = Program_lineNumberWidth(self);
+  for (i = 0; i < self->size; ++i)
     {
       String_new(&s);
-      Token_toString(this->code[i], (struct Token *)0, &s, &indent, w);
+      Token_toString(self->code[i], (struct Token *)0, &s, &indent, w);
       if ((from == (struct Pc *)0 || from->line <= i) &&
           (to == (struct Pc *)0 || to->line >= i))
         {
@@ -750,14 +750,14 @@ struct Value *Program_list(struct Program *this, int dev, int watchIntr,
   return (struct Value *)0;
 }
 
-struct Value *Program_analyse(struct Program *this, struct Pc *pc,
+struct Value *Program_analyse(struct Program *self, struct Pc *pc,
                               struct Value *value)
 {
   int i;
 
-  for (i = 0; i < this->size; ++i)
+  for (i = 0; i < self->size; ++i)
     {
-      pc->token = this->code[i];
+      pc->token = self->code[i];
       pc->line = i;
       if (pc->token->type == T_INTEGER || pc->token->type == T_UNNUMBERED)
         {
@@ -819,14 +819,14 @@ struct Value *Program_analyse(struct Program *this, struct Pc *pc,
   return (struct Value *)0;
 }
 
-void Program_renum(struct Program *this, int first, int inc)
+void Program_renum(struct Program *self, int first, int inc)
 {
   int i;
   struct Token *token;
 
-  for (i = 0; i < this->size; ++i)
+  for (i = 0; i < self->size; ++i)
     {
-      for (token = this->code[i]; token->type != T_EOL; )
+      for (token = self->code[i]; token->type != T_EOL; )
         {
           if (token->type == T_GOTO || token->type == T_GOSUB ||
               token->type == T_RESTORE || token->type == T_RESUME ||
@@ -837,7 +837,7 @@ void Program_renum(struct Program *this, int first, int inc)
                 {
                   struct Pc dst;
 
-                  if (Program_goLine(this, token->u.integer, &dst))
+                  if (Program_goLine(self, token->u.integer, &dst))
                     {
                       token->u.integer = first + dst.line * inc;
                     }
@@ -860,30 +860,30 @@ void Program_renum(struct Program *this, int first, int inc)
         }
     }
 
-  for (i = 0; i < this->size; ++i)
+  for (i = 0; i < self->size; ++i)
     {
-      assert(this->code[i]->type == T_INTEGER ||
-             this->code[i]->type == T_UNNUMBERED);
-      this->code[i]->type = T_INTEGER;
-      this->code[i]->u.integer = first + i * inc;
+      assert(self->code[i]->type == T_INTEGER ||
+             self->code[i]->type == T_UNNUMBERED);
+      self->code[i]->type = T_INTEGER;
+      self->code[i]->u.integer = first + i * inc;
     }
 
-  this->numbered = 1;
-  this->runnable = 0;
-  this->unsaved = 1;
+  self->numbered = 1;
+  self->runnable = 0;
+  self->unsaved = 1;
 }
 
-void Program_unnum(struct Program *this)
+void Program_unnum(struct Program *self)
 {
   char *ref;
   int i;
   struct Token *token;
 
-  ref = malloc(this->size);
-  memset(ref, 0, this->size);
-  for (i = 0; i < this->size; ++i)
+  ref = malloc(self->size);
+  memset(ref, 0, self->size);
+  for (i = 0; i < self->size; ++i)
     {
-      for (token = this->code[i]; token->type != T_EOL; ++token)
+      for (token = self->code[i]; token->type != T_EOL; ++token)
         {
           if (token->type == T_GOTO || token->type == T_GOSUB ||
               token->type == T_RESTORE || token->type == T_RESUME)
@@ -893,7 +893,7 @@ void Program_unnum(struct Program *this)
                 {
                   struct Pc dst;
 
-                  if (Program_goLine(this, token->u.integer, &dst))
+                  if (Program_goLine(self, token->u.integer, &dst))
                     {
                       ref[dst.line] = 1;
                     }
@@ -912,32 +912,32 @@ void Program_unnum(struct Program *this)
         }
     }
 
-  for (i = 0; i < this->size; ++i)
+  for (i = 0; i < self->size; ++i)
     {
-      assert(this->code[i]->type == T_INTEGER ||
-             this->code[i]->type == T_UNNUMBERED);
+      assert(self->code[i]->type == T_INTEGER ||
+             self->code[i]->type == T_UNNUMBERED);
       if (!ref[i])
         {
-          this->code[i]->type = T_UNNUMBERED;
-          this->numbered = 0;
+          self->code[i]->type = T_UNNUMBERED;
+          self->numbered = 0;
         }
     }
 
   free(ref);
-  this->runnable = 0;
-  this->unsaved = 1;
+  self->runnable = 0;
+  self->unsaved = 1;
 }
 
-int Program_setname(struct Program *this, const char *filename)
+int Program_setname(struct Program *self, const char *filename)
 {
-  if (this->name.length)
+  if (self->name.length)
     {
-      String_delete(&this->name, 0, this->name.length);
+      String_delete(&self->name, 0, self->name.length);
     }
 
   if (filename)
     {
-      return String_appendChars(&this->name, filename);
+      return String_appendChars(&self->name, filename);
     }
   else
     {
@@ -945,7 +945,7 @@ int Program_setname(struct Program *this, const char *filename)
     }
 }
 
-void Program_xref(struct Program *this, int chn)
+void Program_xref(struct Program *self, int chn)
 {
   struct Pc pc;
   struct Xref *func;
@@ -954,17 +954,17 @@ void Program_xref(struct Program *this, int chn)
   struct Xref *goto_;
   int nl = 0;
 
-  assert(this->runnable);
+  assert(self->runnable);
   func = (struct Xref *)0;
   var = (struct Xref *)0;
   gosub = (struct Xref *)0;
   goto_ = (struct Xref *)0;
 
-  for (pc.line = 0; pc.line < this->size; ++pc.line)
+  for (pc.line = 0; pc.line < self->size; ++pc.line)
     {
       struct On *on;
 
-      for (on = (struct On *)0, pc.token = this->code[pc.line];
+      for (on = (struct On *)0, pc.token = self->code[pc.line];
            pc.token->type != T_EOL; ++pc.token)
         {
           switch (pc.token->type)
@@ -1021,9 +1021,9 @@ void Program_xref(struct Program *this, int chn)
         }
     }
 
-  for (pc.line = 0; pc.line < this->size; ++pc.line)
+  for (pc.line = 0; pc.line < self->size; ++pc.line)
     {
-      for (pc.token = this->code[pc.line]; pc.token->type != T_EOL;
+      for (pc.token = self->code[pc.line]; pc.token->type != T_EOL;
            ++pc.token)
         {
           switch (pc.token->type)
@@ -1075,7 +1075,7 @@ void Program_xref(struct Program *this, int chn)
   if (func)
     {
       FS_putChars(chn, _("Function Referenced in line\n"));
-      Xref_print(func, printName, this, chn);
+      Xref_print(func, printName, self, chn);
       Xref_destroy(func);
       nl = 1;
     }
@@ -1088,7 +1088,7 @@ void Program_xref(struct Program *this, int chn)
         }
 
       FS_putChars(chn, _("Variable Referenced in line\n"));
-      Xref_print(var, printName, this, chn);
+      Xref_print(var, printName, self, chn);
       Xref_destroy(func);
       nl = 1;
     }
@@ -1101,7 +1101,7 @@ void Program_xref(struct Program *this, int chn)
         }
 
       FS_putChars(chn, _("Gosub    Referenced in line\n"));
-      Xref_print(gosub, printLine, this, chn);
+      Xref_print(gosub, printLine, self, chn);
       Xref_destroy(gosub);
       nl = 1;
     }
@@ -1114,7 +1114,7 @@ void Program_xref(struct Program *this, int chn)
         }
 
       FS_putChars(chn, _("Goto     Referenced in line\n"));
-      Xref_print(goto_, printLine, this, chn);
+      Xref_print(goto_, printLine, self, chn);
       Xref_destroy(goto_);
     }
 }
