@@ -22,8 +22,11 @@
 #define _TOYWASM_CONFIG_H
 
 #define TOYWASM_USE_SEPARATE_EXECUTE
+#define TOYWASM_USE_TAILCALL
+#define TOYWASM_SORT_EXPORTS
 #define TOYWASM_USE_JUMP_BINARY_SEARCH
 #define TOYWASM_JUMP_CACHE2_SIZE 4
+#define TOYWASM_USE_LOCALS_FAST_PATH
 #define TOYWASM_USE_LOCALS_CACHE
 #define TOYWASM_USE_SEPARATE_LOCALS
 #define TOYWASM_USE_SMALL_CELLS
@@ -37,5 +40,7 @@
 #define TOYWASM_ENABLE_WASM_THREADS
 #define TOYWASM_ENABLE_WASI
 #define TOYWASM_ENABLE_WASI_THREADS
+#define TOYWASM_ENABLE_DYLD
+#define TOYWASM_ENABLE_DYLD_DLFCN
 
 #endif /* !defined(_TOYWASM_CONFIG_H) */
