@@ -26,17 +26,20 @@
  * Public Data
  ****************************************************************************/
 
-const char *toywasm_config_string =
+const char *const toywasm_config_string =
 "\tTOYWASM_USE_SEPARATE_EXECUTE = ON\n"
-"\tTOYWASM_USE_TAILCALL = OFF\n"
+"\tTOYWASM_USE_TAILCALL = ON\n"
+"\tTOYWASM_FORCE_USE_TAILCALL = OFF\n"
 "\tTOYWASM_USE_SIMD = OFF\n"
 "\tTOYWASM_USE_SHORT_ENUMS = OFF\n"
 "\tTOYWASM_USE_USER_SCHED = OFF\n"
 "\tTOYWASM_ENABLE_TRACING = OFF\n"
 "\tTOYWASM_ENABLE_TRACING_INSN = OFF\n"
+"\tTOYWASM_SORT_EXPORTS = ON\n"
 "\tTOYWASM_USE_JUMP_BINARY_SEARCH = ON\n"
 "\tTOYWASM_USE_JUMP_CACHE = OFF\n"
 "\tTOYWASM_JUMP_CACHE2_SIZE = 4\n"
+"\tTOYWASM_USE_LOCALS_FAST_PATH = ON\n"
 "\tTOYWASM_USE_LOCALS_CACHE = ON\n"
 "\tTOYWASM_USE_SEPARATE_LOCALS = ON\n"
 "\tTOYWASM_USE_SMALL_CELLS = ON\n"
@@ -50,4 +53,6 @@ const char *toywasm_config_string =
 "\tTOYWASM_ENABLE_WASM_TAILCALL = ON\n"
 "\tTOYWASM_ENABLE_WASM_THREADS = ON\n"
 "\tTOYWASM_ENABLE_WASI = ON\n"
-"\tTOYWASM_ENABLE_WASI_THREADS = ON\n";
+"\tTOYWASM_ENABLE_WASI_THREADS = ON\n"
+"\tTOYWASM_ENABLE_DYLD = ON\n"
+"\tTOYWASM_ENABLE_DYLD_DLFCN = ON\n";
