@@ -207,8 +207,13 @@
  * signal indicating a change in network status.
  */
 
-#define LONG_TIME_SEC    (60*60) /* One hour in seconds */
-#define SHORT_TIME_SEC   (2)     /* 2 seconds */
+#ifdef CONFIG_SYSTEM_TIME64
+#  define LONG_TIME_SEC    (60*60)   /* One hour in seconds */
+#else
+#  define LONG_TIME_SEC    (5*60)    /* Five minutes in seconds */
+#endif
+
+#define SHORT_TIME_SEC     (2)       /* 2 seconds */
 
 /****************************************************************************
  * Private Data
@@ -873,6 +878,11 @@ static int netinit_monitor(void)
                   goto errout_with_notification;
                 }
 
+#ifdef CONFIG_NET_ICMPv6_AUTOCONF
+              /* Perform ICMPv6 auto-configuration */
+
+              netlib_icmpv6_autoconfiguration(ifr.ifr_name);
+#endif
               /* And wait for a short delay.  We will want to recheck the
                * link status again soon.
                */
