@@ -25,6 +25,7 @@
 #include <nuttx/config.h>
 
 #include <sys/types.h>
+#include <sys/ioctl.h>
 #include <ctype.h>
 #include <inttypes.h>
 #include <stdint.h>
@@ -49,14 +50,12 @@
 #  include <sys/boardctl.h>
 #  include <nuttx/drivers/ramdisk.h>
 #  ifdef CONFIG_DEV_LOOP
-#    include <sys/ioctl.h>
 #    include <nuttx/fs/loop.h>
 #  endif
 #  ifdef CONFIG_FS_SMARTFS
 #    include "fsutils/mksmartfs.h"
 #  endif
 #  ifdef CONFIG_SMART_DEV_LOOP
-#    include <sys/ioctl.h>
 #    include <nuttx/fs/smart.h>
 #  endif
 #  ifdef CONFIG_MTD_LOOP
@@ -290,20 +289,20 @@ static int ls_handler(FAR struct nsh_vtbl_s *vtbl, FAR const char *dirpath,
             {
               if (buf.st_size >= GB)
                 {
-                  nsh_output(vtbl, "%7.1fG", (float)buf.st_size / GB);
+                  nsh_output(vtbl, "%11.1fG", (float)buf.st_size / GB);
                 }
               else if (buf.st_size >= MB)
                 {
-                  nsh_output(vtbl, "%7.1fM", (float)buf.st_size / MB);
+                  nsh_output(vtbl, "%11.1fM", (float)buf.st_size / MB);
                 }
               else
                 {
-                  nsh_output(vtbl, "%7.1fK", (float)buf.st_size / KB);
+                  nsh_output(vtbl, "%11.1fK", (float)buf.st_size / KB);
                 }
             }
           else
             {
-              nsh_output(vtbl, "%8" PRIdOFF, buf.st_size);
+              nsh_output(vtbl, "%12" PRIdOFF, buf.st_size);
             }
         }
     }
@@ -572,9 +571,43 @@ int cmd_cat(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
 #if defined(CONFIG_SYSLOG_DEVPATH) && !defined(CONFIG_NSH_DISABLE_DMESG)
 int cmd_dmesg(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
 {
-  UNUSED(argc);
+  int ret = ERROR;
+  int fd;
+  int option;
 
-  return nsh_catfile(vtbl, argv[0], CONFIG_SYSLOG_DEVPATH);
+  if (argc > 1 && (option = getopt(argc, argv, "cC:")) != ERROR)
+    {
+      switch (option)
+      {
+        case 'c':
+          ret = nsh_catfile(vtbl, argv[0], CONFIG_SYSLOG_DEVPATH);
+
+          /* Go through */
+
+        case 'C':
+          fd = open(CONFIG_SYSLOG_DEVPATH, O_RDONLY);
+          if (fd < 0)
+            {
+              nsh_error(vtbl, g_fmtcmdfailed, argv[0], "open", NSH_ERRNO);
+              return fd;
+            }
+
+          ret = ioctl(fd, BIOC_FLUSH, 0);
+          if (ret < 0)
+            {
+              nsh_error(vtbl, g_fmtcmdfailed, argv[0], "ioctl", NSH_ERRNO);
+            }
+
+          close(fd);
+          break;
+      }
+    }
+  else
+    {
+      ret = nsh_catfile(vtbl, argv[0], CONFIG_SYSLOG_DEVPATH);
+    }
+
+  return ret;
 }
 #endif
 
@@ -798,13 +831,13 @@ int cmd_losetup(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
   /* Get the losetup options:  Two forms are supported:
    *
    *   losetup -d <loop-device>
-   *   losetup [-o <offset>] [-r] [-s <sectsize> ] <loop-device> <filename>
+   *   losetup [-o <offset>] [-r] [-b <sectsize> ] <loop-device> <filename>
    *
    * NOTE that the -o and -r options are accepted with the -d option, but
    * will be ignored.
    */
 
-  while ((option = getopt(argc, argv, "d:o:rs:")) != ERROR)
+  while ((option = getopt(argc, argv, "d:o:rb:")) != ERROR)
     {
       switch (option)
         {
@@ -821,7 +854,7 @@ int cmd_losetup(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
           readonly = true;
           break;
 
-        case 's':
+        case 'b':
           sectsize = atoi(optarg);
           break;
 
@@ -1131,14 +1164,14 @@ int cmd_lomtd(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
   /* Get the lomtd options:  Two forms are supported:
    *
    *   lomtd -d <loop-device>
-   *   lomtd [-o <offset>] [-e erasesize] [-s sectsize]
+   *   lomtd [-o <offset>] [-e erasesize] [-b sectsize]
    *         <loop-device> <filename>
    *
    * NOTE that the -o and -r options are accepted with the -d option, but
    * will be ignored.
    */
 
-  while ((option = getopt(argc, argv, "d:o:e:s:")) != ERROR)
+  while ((option = getopt(argc, argv, "d:o:e:b:")) != ERROR)
     {
       switch (option)
         {
@@ -1155,7 +1188,7 @@ int cmd_lomtd(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
           offset = atoi(optarg);
           break;
 
-        case 's':
+        case 'b':
           sectsize = atoi(optarg);
           break;
 
