@@ -550,11 +550,15 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
 #ifdef CONFIG_NET_IPv4
   struct in_addr addr;
   in_addr_t gip = INADDR_ANY;
+  in_addr_t mip;
 #endif
 #ifdef CONFIG_NET_IPv6
   struct in6_addr addr6;
   struct in6_addr gip6 = IN6ADDR_ANY_INIT;
   FAR char *preflen = NULL;
+#  ifdef CONFIG_NETDEV_MULTIPLE_IPv6
+  bool remove = false;
+#  endif
 #endif
   int i;
   FAR char *ifname = NULL;
@@ -717,8 +721,14 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
 #endif
               else if (!strcmp(tmp, "add"))
                 {
-                  /* Compatible with linux IPv6 command, do nothing. */
-
+#if defined(CONFIG_NET_IPv6) && defined(CONFIG_NETDEV_MULTIPLE_IPv6)
+                  remove = false;
+                  continue;
+                }
+              else if (!strcmp(tmp, "del"))
+                {
+                  remove = true;
+#endif
                   continue;
                 }
               else if (!strcmp(tmp, "mtu"))
@@ -802,10 +812,17 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
             }
 
           ninfo("Host IP: %s\n", hostip);
-          inet_pton(AF_INET6, hostip, &addr6);
+          ret = inet_pton(AF_INET6, hostip, &addr6);
+          if (ret <= 0)
+            {
+              nsh_error(vtbl, g_fmtarginvalid, argv[0]);
+              return ERROR;
+            }
         }
 
+#ifndef CONFIG_NETDEV_MULTIPLE_IPv6
       netlib_set_ipv6addr(ifname, &addr6);
+#endif
     }
 #endif /* CONFIG_NET_IPv6 */
 
@@ -844,54 +861,6 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
     }
 #endif /* CONFIG_NET_IPv4 */
 
-  /* Set gateway */
-
-#ifdef CONFIG_NET_IPv6
-#ifdef CONFIG_NET_IPv4
-  if (inet6)
-#endif
-    {
-      /* Only set the gateway address if it was explicitly provided. */
-
-      if (gwip != NULL)
-        {
-          ninfo("Gateway: %s\n", gwip);
-          inet_pton(AF_INET6, gwip, &addr6);
-
-          netlib_set_dripv6addr(ifname, &addr6);
-          gip6 = addr6;
-        }
-    }
-#endif /* CONFIG_NET_IPv6 */
-
-#ifdef CONFIG_NET_IPv4
-#ifdef CONFIG_NET_IPv6
-  else
-#endif
-    {
-      if (gwip != NULL)
-        {
-          ninfo("Gateway: %s\n", gwip);
-          gip = addr.s_addr = inet_addr(gwip);
-        }
-      else
-        {
-          if (gip != 0)
-            {
-              ninfo("Gateway: default\n");
-              gip  = NTOHL(gip);
-              gip &= ~0x000000ff;
-              gip |= 0x00000001;
-              gip  = HTONL(gip);
-            }
-
-          addr.s_addr = gip;
-        }
-
-      netlib_set_dripv4addr(ifname, &addr);
-    }
-#endif /* CONFIG_NET_IPv4 */
-
   /* Set network mask */
 
 #ifdef CONFIG_NET_IPv6
@@ -899,23 +868,53 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
   if (inet6)
 #endif
     {
+      struct in6_addr mask6;
+#ifdef CONFIG_NETDEV_MULTIPLE_IPv6
+      uint8_t plen;
+#endif
       if (mask != NULL)
         {
           ninfo("Netmask: %s\n", mask);
-          inet_pton(AF_INET6, mask, &addr6);
+          ret = inet_pton(AF_INET6, mask, &mask6);
+          if (ret <= 0)
+            {
+              nsh_error(vtbl, g_fmtarginvalid, argv[0]);
+              return ERROR;
+            }
         }
       else if (preflen != NULL)
         {
           ninfo("Prefixlen: %s\n", preflen);
-          netlib_prefix2ipv6netmask(atoi(preflen), &addr6);
+          netlib_prefix2ipv6netmask(atoi(preflen), &mask6);
         }
       else
         {
           ninfo("Netmask: Default\n");
-          inet_pton(AF_INET6, "ffff:ffff:ffff:ffff::", &addr6);
+          inet_pton(AF_INET6, "ffff:ffff:ffff:ffff::", &mask6);
         }
 
-      netlib_set_ipv6netmask(ifname, &addr6);
+#ifdef CONFIG_NETDEV_MULTIPLE_IPv6
+      plen = netlib_ipv6netmask2prefix(mask6.in6_u.u6_addr16);
+      if (remove)
+        {
+          ret = netlib_del_ipv6addr(ifname, &addr6, plen);
+        }
+      else
+        {
+          ret = netlib_add_ipv6addr(ifname, &addr6, plen);
+        }
+
+      if (ret < 0)
+        {
+          perror("Failed to manage IPv6 address");
+
+          /* REVISIT: Should we return ERROR or just let it go? */
+
+          return ERROR;
+        }
+#else
+      netlib_set_ipv6netmask(ifname, &mask6);
+#endif /* CONFIG_NETDEV_MULTIPLE_IPv6 */
     }
 #endif /* CONFIG_NET_IPv6 */
 
@@ -935,10 +934,64 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
           addr.s_addr = inet_addr("255.255.255.0");
         }
 
+      mip = addr.s_addr;
       netlib_set_ipv4netmask(ifname, &addr);
     }
 #endif /* CONFIG_NET_IPv4 */
 
+  /* Set gateway */
+
+#ifdef CONFIG_NET_IPv6
+#ifdef CONFIG_NET_IPv4
+  if (inet6)
+#endif
+    {
+      /* Only set the gateway address if it was explicitly provided. */
+
+      if (gwip != NULL)
+        {
+          ninfo("Gateway: %s\n", gwip);
+          ret = inet_pton(AF_INET6, gwip, &addr6);
+          if (ret <= 0)
+            {
+              nsh_error(vtbl, g_fmtarginvalid, argv[0]);
+              return ERROR;
+            }
+
+          netlib_set_dripv6addr(ifname, &addr6);
+          gip6 = addr6;
+        }
+    }
+#endif /* CONFIG_NET_IPv6 */
+
+#ifdef CONFIG_NET_IPv4
+#ifdef CONFIG_NET_IPv6
+  else
+#endif
+    {
+      if (gwip != NULL)
+        {
+          ninfo("Gateway: %s\n", gwip);
+          gip = addr.s_addr = inet_addr(gwip);
+        }
+      else
+        {
+          if (gip != INADDR_ANY)
+            {
+              ninfo("Gateway: default\n");
+              gip  = ntohl(gip);
+              gip &= ntohl(mip);
+              gip |= 0x00000001;
+              gip  = htonl(gip);
+            }
+
+          addr.s_addr = gip;
+        }
+
+      netlib_set_dripv4addr(ifname, &addr);
+    }
+#endif /* CONFIG_NET_IPv4 */
+
   UNUSED(ifname); /* Not used in all configurations */
 
 #if defined(CONFIG_NETINIT_DHCPC) || defined(CONFIG_NETINIT_DNS)
@@ -950,7 +1003,12 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
       if (dns != NULL)
         {
           ninfo("DNS: %s\n", dns);
-          inet_pton(AF_INET6, dns, &addr6);
+          ret = inet_pton(AF_INET6, dns, &addr6);
+          if (ret <= 0)
+            {
+              nsh_error(vtbl, g_fmtarginvalid, argv[0]);
+              return ERROR;
+            }
         }
       else
         {
