@@ -32,6 +32,7 @@
 
 #include <sys/types.h>
 #include <sys/ioctl.h>
+#include <sys/param.h>
 #include <crypto/rijndael.h>
 #include <crypto/cryptodev.h>
 #include <err.h>
@@ -1727,7 +1728,6 @@ struct aes_xts_tv aes_xts_test_vectors[] =
     },
   },
 };
-#define N_VECTORS (sizeof(aes_xts_test_vectors) / sizeof(*aes_xts_test_vectors))
 
 static int match(FAR unsigned char *a, FAR unsigned char *b, size_t len)
 {
@@ -1837,7 +1837,7 @@ int main(int argc, FAR char **argv)
   int fail = 0;
   size_t i;
 
-  for (i = 0; i < N_VECTORS; i++)
+  for (i = 0; i < nitems(aes_xts_test_vectors); i++)
     {
       tv = &aes_xts_test_vectors[i];
 
