@@ -43,7 +43,7 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define WAKEUP_SIGNAL 17
+#define WAKEUP_SIGNAL SIGRTMIN
 #define SIGVALUE_INT  42
 
 /****************************************************************************
@@ -328,4 +328,6 @@ void sighand_test(void)
 
   printf("sighand_test: done\n");
   FFLUSH();
+  sem_destroy(&sem2);
+  sem_destroy(&sem1);
 }
